( cd usr/lib/mono/boo ; rm -rf Boo.Lang.dll )
( cd usr/lib/mono/boo ; ln -sf ../gac/Boo.Lang/0.5.5.1651__32c39770e9a21a67/Boo.Lang.dll Boo.Lang.dll )
( cd usr/lib/mono/boo ; rm -rf Boo.Lang.Useful.dll )
( cd usr/lib/mono/boo ; ln -sf ../gac/Boo.Lang.Useful/0.5.5.1651__32c39770e9a21a67/Boo.Lang.Useful.dll Boo.Lang.Useful.dll )
( cd usr/lib/mono/boo ; rm -rf Boo.Lang.Compiler.dll )
( cd usr/lib/mono/boo ; ln -sf ../gac/Boo.Lang.Compiler/0.5.5.1651__32c39770e9a21a67/Boo.Lang.Compiler.dll Boo.Lang.Compiler.dll )
( cd usr/lib/mono/boo ; rm -rf Boo.Lang.Parser.dll )
( cd usr/lib/mono/boo ; ln -sf ../gac/Boo.Lang.Parser/0.5.5.1651__32c39770e9a21a67/Boo.Lang.Parser.dll Boo.Lang.Parser.dll )
( cd usr/lib/mono/boo ; rm -rf Boo.Lang.Interpreter.dll )
( cd usr/lib/mono/boo ; ln -sf ../gac/Boo.Lang.Interpreter/0.5.5.1651__32c39770e9a21a67/Boo.Lang.Interpreter.dll Boo.Lang.Interpreter.dll )
( cd usr/lib/mono/boo ; rm -rf Boo.Lang.CodeDom.dll )
( cd usr/lib/mono/boo ; ln -sf ../gac/Boo.Lang.CodeDom/0.5.5.1651__32c39770e9a21a67/Boo.Lang.CodeDom.dll Boo.Lang.CodeDom.dll )
